@@ -680,6 +680,8 @@ class ConsumerThread(Thread):
                                    password=self.amqp_credentials.password,
                                    virtual_host=self.amqp_credentials.vhost,
                                    ssl=self.amqp_credentials.ssl)
+
+                self.consumer.close()
                                    
                 self.consumer = Consumer(connection=self.amqpconn,
                                  queue=self.client_id + '_client_queue',
@@ -781,6 +783,8 @@ class PublisherThread(Thread):
                                    virtual_host=self.amqp_credentials.vhost,
                                    ssl=self.amqp_credentials.ssl)
 
+                    self.publisher.close()
+
                     self.publisher = Publisher(connection=self.amqpconn,
                                    exchange=self.server_id + "_server_exchange",
                                    routing_key=self.server_id + "_server_routing_key",
